/**
  *  \file client/dialogs/simedit.cc
  *  \brief Simulator Edit Dialogs
  */

#include "client/dialogs/simedit.h"
#include "util/nls.h"
#include "game/spec.h"
#include "ui/listbox.h"
#include "game/config.h"
#include "game/exp.h"
#include "game/sim.h"
#include "cpluslib/format.h"
#include "game/racename.h"

/** Graphically edit owner of an object in the simulation. */
bool
editOwner(GSimObject& obj)
{
    UIStringList list;
    for (int i = 1; i <= NUM_OWNERS; ++i)
        list.add(i, format("%X - %s", i, player_racenames.getShortName(i)));

    UIStandardListbox box(0, list.getCount(), font_ems[FONT_NORMAL] * 15, list);
    box.scrollToKey(obj.getOwner());
    if (box.doStandardListbox(_("Set Owner"))) {
        obj.setOwner(box.getKey());
        return true;
    } else {
        return false;
    }
}

/** Graphically edit experience level of an object in the simulation. */
bool
editExperienceLevel(GSimObject& obj)
{
    if (config.NumExperienceLevels() > 0) {
        UIStringList list;
        for (int i = 0; i <= config.NumExperienceLevels(); ++i)
            list.add(i, format("%X - %s", i, getExperienceLevelName(i)));

        UIStandardListbox box(0, list.getCount(), font_ems[FONT_NORMAL] * 20, list);
        box.scrollToKey(obj.getExperienceLevel());
        if (box.doStandardListbox(_("Set Experience Level"))) {
            obj.setExperienceLevel(box.getKey());
            return true;
        } else {
            return false;
        }
    } else {
        return false;
    }
}

