/**
  *  \file util/filepars.h
  *  \brief File Parser
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UTIL_FILEPARS_H
#define PCC_V2_UTIL_FILEPARS_H

#include "cpluslib/string.h"
#include "util/recode.h"

class Stream;
class TextFile;

/** File parser. Processes a file that can possibly contain comments,
    and hands it line-by-line to process() or unparsed(). */
class FileParser {
    string_t name;
    const char* comment_chars;
    bool utf8;
    CharacterSet charset;
 public:
    virtual void process(int line_id, string_t line);
    virtual void unparsed(int line_id, string_t line);

    FileParser(const char* comment_chars);

    virtual ~FileParser()
        { }

    void parseFile(Stream& s);
    bool parseGameFile(string_t filename);

    /** Get file name. \returns the file name previously set with
        setFileName(), which see. */
    const string_t& getFileName() const
        { return name; }

    void trimComments(string_t& line);

    void setCharacterSet(CharacterSet cs);
    void setUtf8();
    void configureTextFile(TextFile& tf);
};

#endif
